@@ -532,7 +532,8 @@ class DynamicSetting(object):
             'max_age': str(self.max_age),
             'allow_fallback': self.fallback_allowed,
             'fallback': self.is_fallback,
-            'source': self.source
+            'source': self.source,
+            'version': self.version
         }
         if not healthy:
             d.update({'reason': reason})
